Chatroom
=========

IRC-style chatroom written in about 500 lines of Python.

##Commands:

* `/me <action> ...`
* `/nick <newname> ...`
* `/msg <user> [msg ...]`
* `/quit [reason ...]`
* `/changepass [newpass]`

## OP required for these:
* `/kick <user> ...`
* `/op <user>` and `/deop <user>`